function ForcedPick(varargin)
% ForcedPick(varargin)
% Usage: User can choose to force a certain pick in a particular range
% Written by: Maor Asher
%--------------------------------------------------------------------------
global comm
if nargin==0
    % Set Default values:
    comm.pos=[240,227,800,550];
    comm.dirname='0';
    comm.existingfile='';
    comm.name='';
    comm.ramp(1:2,1:5)=-1;
    comm.movie=0;
    comm.plot=0;
    comm.UseFilter=0;
    comm.LoadParamaters=0;
    comm.path1='';
    comm.path2='';
    comm.spath1='';
    comm.spath2='';
else
    comm=varargin{1};
end
par=load([comm.dirname,'\','par.mat']);
Fpick=figure('Position',[350,350,300,400],'Color','White','MenuBar','none','NumberTitle','off','Name','Impedance Spectroscopy Genetic Programming','Resize','off','Tag','Fpick');
if nargin==0
    movegui(Fpick,'center')
end
handles=guihandles;
guidata(Fpick, handles);

%------------ Buttons: ------------%
inimutpnl=uipanel('Title','Forced Peaks','FontSize',10,'Parent',handles.Fpick,'Units','pixels','Position',[5,5,295,395],'BackgroundColor','White');

% Help:
handles.help=uicontrol('Style','pushbutton','Units','pixels','Position',[10,10,70,25],'FontWeight','bold','String','Help');

% OK:
handles.OK=uicontrol('Style','pushbutton','Units','pixels','Position',[220,10,70,25],'FontWeight','bold','Enable','on','String','OK');

% Cancle:
handles.Cancle=uicontrol('Style','pushbutton','Units','pixels','Position',[140,10,70,25],'FontWeight','bold','String','Cancle');

%------------ text: ------------%
% text: "lb":
handles.lb.txt=uicontrol('Style','text','Units','pixels','Position',[190,350,30,20],'BackgroundColor','White','FontSize',10,'FontWeight','bold','HorizontalAlignment','center','Parent',inimutpnl,'String','lb');

% text: "ub":
handles.ub.txt=uicontrol('Style','text','Units','pixels','Position',[240,350,30,20],'BackgroundColor','White','FontSize',10,'FontWeight','bold','HorizontalAlignment','center','Parent',inimutpnl,'String','ub');

%------------ radio buttons: ------------%
handles.h=uibuttongroup('Units','pixels','Position',[0,0,295,350],'BackgroundColor','White','FontSize',10,'FontWeight','bold','Parent',inimutpnl,'visible','off');
handles.G=uicontrol('Style','Radio','BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','Parent', handles.h,'pos',[10,315,100,30],'Tag','G','HandleVisibility','off','String','Gaussian');
handles.Glb=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[190,320,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(1)));
handles.Gub=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[240,320,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(2)));
handles.L=uicontrol('Style','Radio','BackgroundColor','White','FontSize',10,'Value',1,'HorizontalAlignment','center','Parent', handles.h,'pos',[10,285,100,30],'Tag','L','HandleVisibility','off','String','Lorenzian');
handles.Llb=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[190,290,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(1)));
handles.Lub=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[240,290,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(2)));
handles.D=uicontrol('Style','Radio','BackgroundColor','White','FontSize',10,'Value',1,'HorizontalAlignment','center','Parent', handles.h,'pos',[10,255,100,30],'Tag','D','HandleVisibility','off','String','Delta Func');
handles.Dlb=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[190,260,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(1)));
handles.Dub=uicontrol('Style','edit','Units','pixels','Parent',inimutpnl,'Enable','off','Position',[240,260,30,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String',num2str(par.forcedpickrange(2)));

if strcmp(par.forcedpick,'L')
    set(handles.Llb,'Enable','on')
    set(handles.Lub,'Enable','on')
end

if strcmp(par.forcedpick,'G')
    set(handles.Glb,'Enable','on')
    set(handles.Gub,'Enable','on')
end

if strcmp(par.forcedpick,'D')
    set(handles.Dlb,'Enable','on')
    set(handles.Dub,'Enable','on')
end

% Initialize some button group properties. 
set(handles.h,'SelectionChangeFcn',{@RBselect,handles});
set(handles.h,'SelectedObject',[]);  % No selection
set(handles.h,'Visible','on');
set(handles.OK,'CallBack',{@PBOK,handles});
set(handles.Cancle,'CallBack',{@PBCancle,handles});
set(handles.help,'CallBack',{@PBHelp,handles});

%------------ Functions: ------------%
% Create
%function CreateFunction()
%clc

% Cancle Button:
function PBCancle(hObject,eventdata,handles) 
delete(handles.Fpick);

% Help Button:
function PBHelp(hObject,eventdata,handles)
web http://electroceramics.technion.ac.il/isgp/help.html

% Ok Button:
function PBOK(hObject,eventdata,handles) 
global par comm
count=0;
if get(handles.G,'Value')==1
    par.forcedpick='G';
    par.forcedpickrange=[str2double(get(handles.Glb,'String')),str2double(get(handles.Gub,'String'))];
else
    count=count+1;
end

if get(handles.L,'Value')==1
    par.forcedpick='L';
    par.forcedpickrange=[str2double(get(handles.Llb,'String')),str2double(get(handles.Lub,'String'))];
    else
    count=count+1;
end

if get(handles.D,'Value')==1
    par.forcedpick='D';
    par.forcedpickrange=[str2double(get(handles.Dlb,'String')),str2double(get(handles.Dub,'String'))];
    else
    count=count+1;
end

if count==3
   par.forcedpick=''; 
end

% proof:
if isnan(par.forcedpickrange(1)) || isinf(par.forcedpickrange(2)) || isnan(par.forcedpickrange(2)) || isinf(par.forcedpickrange(1))
    errordlg('the lower and upper bound must be a number','error','modal');
    return
end

if par.forcedpickrange(1)>= par.forcedpickrange(2)
    errordlg('the lower bound must be lower than the upper bound','error','modal');
    return
end

if  par.forcedpickrange(1)<-20
    errordlg('the lower bound must be above -20','error','modal');
    return
end

if  par.forcedpickrange(2)>20
    errordlg('the upper bound must be below 20','error','modal');
    return
end

save([comm.dirname,'\','par.mat'],'-struct','par');
delete(handles.Fpick)

function RBselect(hObject,eventdata,handles)
if get(handles.G,'Value')==1
    set(handles.Glb,'Enable','on')
    set(handles.Gub,'Enable','on')
else
    set(handles.Glb,'Enable','off')
    set(handles.Gub,'Enable','off')
end

if get(handles.L,'Value')==1
    set(handles.Llb,'Enable','on')
    set(handles.Lub,'Enable','on')
else
    set(handles.Llb,'Enable','off')
    set(handles.Lub,'Enable','off')
end

if get(handles.D,'Value')==1
    set(handles.Dlb,'Enable','on')
    set(handles.Dub,'Enable','on')
else
    set(handles.Dlb,'Enable','off')
    set(handles.Dub,'Enable','off')
end