function LoadData(varargin)
% LoadData(varargin)
% Usage: This function loads two data sets, uses KK and a filter.
% varargin = {comm}
% The comm structure is the communication factor between the screens.
% comm.pos = The last figure position. The current figure will take its place.
% comm.dirname = The name of the work directory.
% comm.name = the project's name.
% comm.movie = Whether the "save movie" check box was checked (project).
% comm.plot = Whether to plot axexs on startup (LoadData)
% comm.UseFilter = Whether the filter was used the last time (LoadData).
% comm.LoadParamaters = Whether the user has changed any of the paramaters (Parameters).
% comm.path1 = The Path to DataSet1.
% comm.path2 = The Path to DataSet2.
% comm.spath1 = The short Path name to DataSet1.
% comm.spath2 = The short Path name to DataSet2.
% Edit.UserData stores the real path.
% Edit.String stores the short path.
% NOTE:
% comm.dirname is the WORKING dir name.
% comm.path# is the DATA dir name.
% in this function, comm is a GLOBAL variable, because the PBLoadSets returns the paths and changes it.
% Credits: Alex Tesler, Yehu David-Horev, Alon Dana, Maor Asher.
% Modified by: Arthur Doroshev
%--------------------------------------------------------------------------
global data data_val comm LoadSetsFlag no_kkt omega_duplicate
% LoadSetsFlag indicates whether the LoadSets button was pressed.
LoadSetsFlag=0;
if nargin==0
    % Set Default values:
    comm.pos=[240,227,800,550];
    comm.dirname='0';
    comm.name='';
    comm.existingfile='';
    comm.ramp(1:2,1:5)=-1;
    comm.movie=0;
    comm.plot=0;
    comm.UseFilter=0;
    comm.LoadParamaters=0;
    comm.path1='';
    comm.path2='';
    comm.spath1='';
    comm.spath2='';
    comm.spath3='';
    comm.spath4='';
    comm.kktcheckbox='';
else
    comm=varargin{1};
end

data=zeros(1,1);
data_val=zeros(1,1);
no_kkt.data=data;
no_kkt.data_val=data_val;
no_kkt.path1='';
no_kkt.path2='';
no_kkt.spath1='';
no_kkt.spath2='';
pos=[240,227,800,550];
screen3=figure('Position',pos,'Color','White','MenuBar','none','NumberTitle','off','Name','Impedance Spectroscopy Genetic Programming','Resize','off','Tag','screen3');
if nargin==0
    movegui(screen3,'center');
end

movegui(screen3,'center');
handles=guihandles;
guidata(screen3,handles);

%------------ Buttons: ------------%
%axes('Parent',screen3,'Units','pixels','Position',[279.5,521,241,29],'CreateFcn',{@header,handles});

% Close:
handles.close=uicontrol('Style','pushbutton','Units','pixels','Position',[10,10,70,25],'FontSize',8,'FontWeight','bold','String','Close');

% Help:
handles.help=uicontrol('Style','pushbutton','Units','pixels','Position',[100,10,70,25],'FontSize',8,'FontWeight','bold','String','Help');

% Next:
handles.next=uicontrol('Style','pushbutton','Units','pixels','Position',[720,10,70,25],'FontSize',8,'FontWeight','bold','String','Next  >');

% Back:
handles.back=uicontrol('Style','pushbutton','Units','pixels','Position',[630,10,70,25],'FontSize',8,'FontWeight','bold','String','<  Back');

% Header:
axes('Parent',screen3,'Units','pixels','Position',[279.5,521,241,29],'CreateFcn',{@header,handles});

% slogo:
%axes('Units','pixels','Position',[0,513,118,37],'CreateFcn',{@slogo,handles});

% get the project name:
len=size(comm.dirname,2);
slash=0;
for ii=1:len
    if strcmp('\',comm.dirname(ii))
        slash=ii;
    end
end

for ii=1:len-slash
    name(1,ii)=comm.dirname(slash+ii);
end

comm.name=name;

% text: Project Name
uicontrol('Style','text','Units','pixels','Position',[645,530,45,20],'BackgroundColor','White','FontSize',9,'HorizontalAlignment','left','String','Project: ');
n=uicontrol('Style','text','Units','pixels','Position',[690,530,110,20],'BackgroundColor','White','FontSize',9,'FontWeight','bold','HorizontalAlignment','left','String',comm.name);

if comm.dirname=='0'
    set(n,'String','No Project Loaded');
    set(n,'ForegroundColor','red');
    set(n,'FontAngle','italic');
    set(n,'FontWeight','normal');
end

% text: "The Filter is not to scale in the Y axis"
handles.NotScale=uicontrol('Style','text','Units','pixels','Position',[350,35,200,20],'Visible','off','BackgroundColor','White','ForegroundColor','black','FontSize',8,'HorizontalAlignment','left','String','(The Filter is not to scale in the Y axis)');

%------------ Axes: ------------%
handles.ax1=axes('Units','pixels','Position',[415,330,365,160],'Visible','off');
handles.ax2=axes('Units','pixels','Position',[415,85,365,160],'Visible','off');

%------------ Load Panel: ------------%
uipanel('Title','Load','FontSize',10,'Parent',handles.screen3,'Units','pixels','Position',[10,370,325,140],'BackgroundColor','White');

% text: "Enter Data Set 1:"
uicontrol('Style','text','Units','pixels','Position',[15,475,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 1:');

% text: "Enter Data Set 2:"
uicontrol('Style','text','Units','pixels','Position',[15,430,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String','Enter Data Set 2:');

% edit 1:
handles.edit1=uicontrol('Style','edit','Units','pixels','Position',[15,455,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath1,'UserData',comm.path1,'Tag','edit1');

% edit 2:
handles.edit2=uicontrol('Style','edit','Units','pixels','Position',[15,410,230,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.spath2,'UserData',comm.path2,'Tag','edit2');

% Browse 1:
uicontrol('Style','pushbutton','Units','pixels','Position',[250,453,70,25],'FontSize',8,'CallBack',{@PBBrowse1,handles},'String','Browse');

% Browse 2:
uicontrol('Style','pushbutton','Units','pixels','Position',[250,408,70,25],'FontSize',8,'CallBack',{@PBBrowse2,handles},'String','Browse');

% Load Sets:
handles.loadsets=uicontrol('Style','pushbutton','Units','pixels','FontSize',8,'Position',[15,377,70,25],'String','Load Sets');

% Additional Sets of Data:
handles.additionalsets=uicontrol('Style','pushbutton','Units','pixels','Position',[90,377,120,25],'FontSize',8,'FontWeight','bold','String','Load Additional Sets');

%------------ KK Panel: ------------%
uipanel('Title','Kramers-Kronig Transforms (KKT)','FontSize',10,'Parent',handles.screen3,'Units','pixels','Position',[10,200,325,160],'BackgroundColor','White');

% KKT check box:
handles.check1=uicontrol('Style','checkbox','Units','pixels','Position',[15,315,90,20],'BackgroundColor','White','FontSize',10,'Max',1,'Min',0,'CallBack',{@CheckBack,handles},'Value',0,'String','Use KKT');

% Data Set 1:
uipanel('Title','Data Set 1','FontSize',10,'Parent',handles.screen3,'Units','pixels','Position',[15,220,150,90],'BackgroundColor','White');

% text1: "Dividing Factor"
handles.RPtext1=uicontrol('Style','text','Units','pixels','Position',[20,265,130,20],'BackgroundColor','White','Enable','off','FontSize',10,'HorizontalAlignment','left','String','Dividing Factor:');

% R Polarization1:
handles.RP1=uicontrol('Style','text','Units','pixels','Position',[110,265,40,20],'BackgroundColor','White','Enable','off','FontSize',10,'HorizontalAlignment','left','String','');

% loglog plot1:
handles.loglog1=uicontrol('Style','pushbutton','Units','pixels','Position',[25,235,60,25],'CallBack',{@KKT,handles,1,1},'Enable','off','String','loglog plot','Tag','loglog1');

% semilog plot1:
handles.semilog1=uicontrol('Style','pushbutton','Units','pixels','Position',[95,235,60,25],'FontSize',8,'CallBack',{@KKT,handles,1,2},'Enable','off','String','semilog plot','Tag','semilog1');

% Data Set 2:
uipanel('Title','Data Set 2','FontSize',10,'Parent',handles.screen3,'Units','pixels','Position',[180,220,150,90],'BackgroundColor','White');

% text2: "Dividing Factor"
handles.RPtext2=uicontrol('Style','text','Units','pixels','Position',[185,265,130,20],'BackgroundColor','White','Enable','off','FontSize',10,'HorizontalAlignment','left','String','Dividing Factor:');

% R Polarization2:
handles.RP2=uicontrol('Style','text','Units','pixels','Position',[275,265,40,20],'BackgroundColor','White','Enable','off','FontSize',10,'HorizontalAlignment','left','String','');

% loglog plot2:
handles.loglog2=uicontrol('Style','pushbutton','Units','pixels','Position',[190,235,60,25],'FontSize',8,'CallBack',{@KKT,handles,2,1},'Enable','off','String','loglog plot','Tag','loglog2');

% semilog plot2:
handles.semilog2=uicontrol('Style','pushbutton','Units','pixels','Position',[260,235,60,25],'FontSize',8,'CallBack',{@KKT,handles,2,2},'Enable','off','String','semilog plot','Tag','semilog2');

%------------ FilterPanel: ------------%
FilterPanel=uipanel('Parent',screen3,'Title','Sigmoid Filter','FontSize',10,'Parent',handles.screen3,'Units','pixels','Position',[10,50,325,140],'BackgroundColor','White','Tag','FilterPanel');

% Omega 0:
handles.w0=uicontrol('Parent',FilterPanel,'Style','edit','Units','pixels','Position',[35,70,60,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String','1','Tag','w0');

% Omega 1:
handles.w1=uicontrol('Parent',FilterPanel,'Style','edit','Units','pixels','Position',[35,40,60,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','center','String','10','Tag','w1');

% View Filter:
handles.PBView=uicontrol('Style','pushbutton','Units','pixels','Position',[15,57,70,25],'FontSize',8,'CallBack',{@PBViewFilter,handles},'Enable','off','String','View Filter','Tag','PBView');

% CheckBox:
handles.CheckBox=uicontrol('Style','checkbox','Units','pixels','Position',[15,150,80,20],'FontSize',10,'CallBack',{@FilterCheckBox,handles},'String','Use Filter','BackgroundColor','White','Max',1,'Min',0,'Value',0);

if comm.UseFilter==1
    set(handles.CheckBox,'Value',1);
end

handles.omega0=uicontrol('Parent',FilterPanel,'Style','text','Units','pixels','Position',[5,70,30,20],'BackgroundColor','White','FontSize',12,'HorizontalAlignment','left','String','w0','FontName','symbol');
handles.omega1=uicontrol('Parent',FilterPanel,'Style','text','Units','pixels','Position',[5,40,30,20],'BackgroundColor','White','FontSize',12,'HorizontalAlignment','left','String','w1','FontName','symbol');
    
% filter jpg:
axes('Units','pixels','Parent',FilterPanel,'Position',[100,5,220,130]);
filterimg=imread('ISGP/filter1.isgp');
imshow(filterimg)
if comm.plot==1
    CreateAxes(handles);
end

% Define Buttons' Callbacks:
set(handles.close,'CallBack',{@PBClose,handles});
set(handles.help,'CallBack',{@PBHelp,handles});
set(handles.next,'CallBack',{@PBNext,handles});
set(handles.back,'CallBack',{@PBBack,handles});
set(handles.loadsets,'CallBack',{@PBLoadSets,handles});
set(handles.check1,'CallBack',{@CheckBack,handles});
set(handles.loglog1,'CallBack',{@KKT,handles,1,1});
set(handles.semilog1,'CallBack',{@KKT,handles,1,2});
set(handles.loglog2,'CallBack',{@KKT,handles,2,1});
set(handles.semilog2,'CallBack',{@KKT,handles,2,2});
set(handles.additionalsets,'CallBack',{@additionalsets1,handles});
set(handles.omega0,'Enable','on');
set(handles.omega1,'Enable','on');

if comm.kktcheckbox==1
    set(handles.check1,'Value',1);
end

% additional sets:
if comm.check==1
    
    if ~isfolder(comm.dirname)
        errordlg('The directory of the project was deleted or moved.','Incorrect File Path','modal');
        return
    end
    
    if strcmp(get(handles.edit1,'String'),'') && strcmp(get(handles.edit2,'String'),'')
    errordlg('Please enter Two data sets, and load them.','No data was entered','modal');
    return
    end
    
    % check whether the data loaded is the data "entered":
    % if the edit boxes differs from the comm.spath#, we know that the
    % user had entered or changed the data, so we'll use the edit#.string:
    flag=0;
    if ~strcmp(comm.spath1,get(handles.edit1,'String'))
        flag=1;
    end

    if ~strcmp(comm.spath2,get(handles.edit2,'String'))
        flag=1;
    end

    % if the data was changed, load it:
    if flag==1 && strcmp(no_kkt.path1,'')
        button=questdlg('The Data Set Paths where changed. Would you like to load the NEW data sets?','Load Confirmation Dialog','Yes','No','Cancel','Yes');
        switch button
            case 'Cancel'
                return
            case 'Yes'
                comm.path1=get(handles.edit1,'String');
                comm.path2=get(handles.edit2,'String');
                err=LoadFcn(handles,0);
                if err==1
                    return
                end
            case 'No'
                set(handles.edit1,'UserData',comm.path1);
                set(handles.edit1,'String',comm.spath1);
                set(handles.edit2,'UserData',comm.path2);
                set(handles.edit2,'String',comm.spath2);
                err=LoadFcn(handles,0);
                if err==1
                    return
                end
        end
    end
    
    % If the data was not loaded via LoadSets Button, load it:
    if LoadSetsFlag==0
        err=LoadFcn(handles,0);
        if err==1
            return
        end
    end
    
    if get(handles.check1,'Value')==0
        button=questdlg('You did not use K-K. Your data will not be normalized. Would you like to continue?','Load Confirmation Dialog','Yes','No','No');
        if strcmp(button,'No')
            return
        end
        comm.path1=no_kkt.path1;
        comm.path2=no_kkt.path2;
        comm.spath1=no_kkt.spath1;
        comm.spath2=no_kkt.spath2;
    else
        comm.kktcheckbox=1;
        if LoadFcn(handles,0)==1 && strcmp(comm.kktcheckbox,'')
            set(handles.check1,'Value',0);
            return
        end
        
        comm.path1=get(handles.edit1,'String');
        comm.path2=get(handles.edit2,'String');
        no_kkt.path1=comm.path1;
        no_kkt.path2=comm.path2;
        no_kkt.spath1=comm.spath1;
        no_kkt.spath2=comm.spath2;
        data=load([comm.dirname,'\','data.gpdat'],'-ascii');
        no_kkt.data=data;
        data_val=load([comm.dirname,'\','data_val.gpdat'],'-ascii');
        no_kkt.data_val=data_val;
        
        try
            f1=data(:,1);
            Re_z1=data(:,2);
            Im_z1=data(:,3);
            f2=data_val(:,1);
            Re_z2=data_val(:,2);
            Im_z2=data_val(:,3);
        catch
            errordlg('Data sets are invalid.','error','modal');
            set(handles.check1,'Value',0);
            return
        end
        
        Rp_KK_1=max(Re_z1);
        set(handles.RP1,'Enable','on');
        set(handles.RP1,'String',num2str(Rp_KK_1));
        Re_z=Re_z1./Rp_KK_1;
        Im_z=Im_z1./Rp_KK_1;
        d=[f1,Re_z,Im_z];
        save([comm.dirname,'\','DataSet1_KKT.txt'],'d','-ascii');
        save([comm.dirname,'\','data.gpdat'],'d','-ascii');
        %comm.path1=[comm.dirname,'\','DataSet1_KKT.txt'];
        %comm.spath1='DataSet1_KKT.txt';
        set(handles.edit1,'String',comm.path1);

        Rp_KK_2=max(Re_z2);
        set(handles.RP2,'Enable','on');
        set(handles.RP2,'String',num2str(Rp_KK_2));
        Re_z=Re_z2./Rp_KK_2;
        Im_z=Im_z2./Rp_KK_2;
        d=[f2,Re_z,Im_z];
        save([comm.dirname,'\','DataSet2_KKT.txt'],'d','-ascii');
        save([comm.dirname,'\','data_val.gpdat'],'d','-ascii');
        %comm.path2=[comm.dirname,'\','DataSet2_KKT.txt'];
        %comm.spath2='DataSet2_KKT.txt';
        set(handles.edit2,'String',comm.path2);
        Rp_KK=0.8*Rp_KK_1+0.2*Rp_KK_2;
        save([comm.dirname,'\','norm_factor.gpdat'],'Rp_KK','-ascii');
    end
    
    comm.UseFilter=get(handles.CheckBox,'Value');
    if comm.UseFilter==0
        w0=0.00001;
        w1=0.001;
    else
        w0=omega_duplicate(:,1);
        w1=omega_duplicate(:,2);
        %w0=str2double(get(handles.w0,'string'));
        %w1=str2double(get(handles.w1,'string'));
    end
    
    omega=[w0,w1];
    save([comm.dirname,'\','omega.gpdat'],'omega','-ascii');
    comm.spath1=get(handles.edit1,'String');
    comm.spath2=get(handles.edit2,'String');
    comm.pos=get(handles.screen3,'Position');
    save([comm.dirname,'\','comm.mat'],'comm');
    comm.plot=1;
    delete(handles.screen3)
    Ramp(comm)
end

%------------ Functions: ------------%
% Create:
%function CreateFunction()
%clc

% KKT checkbox:
function CheckBack(hObject,eventdata,handles) 
global data data_val comm no_kkt
if get(handles.check1,'Value')==1
    comm.kktcheckbox=1;
    if LoadFcn(handles,0)==1 && strcmp(comm.kktcheckbox,'')
        set(handles.check1,'Value',0);
        return
    end
    comm.path1=get(handles.edit1,'String');
    comm.path2=get(handles.edit2,'String');
    no_kkt.path1=comm.path1;
    no_kkt.path2=comm.path2;
    no_kkt.spath1=comm.spath1;
    no_kkt.spath2=comm.spath2;
    data=load([comm.dirname,'\','data.gpdat'],'-ascii');
    no_kkt.data=data;
    data_val=load([comm.dirname,'\','data_val.gpdat'],'-ascii');
    no_kkt.data_val=data_val;
    try
        f1=data(:,1);
        Re_z1=data(:,2);
        Im_z1=data(:,3);
        f2=data_val(:,1);
        Re_z2=data_val(:,2);
        Im_z2=data_val(:,3);
    catch
        errordlg('Data sets are invalid.','error','modal');
        set(handles.check1,'Value',0);
        return
    end
    
    set(handles.RPtext1,'Enable','on');
    set(handles.RPtext2,'Enable','on');
    set(handles.loglog1,'Enable','on');
    set(handles.semilog1,'Enable','on');
    set(handles.loglog2,'Enable','on');
    set(handles.semilog2,'Enable','on');

    Rp_KK_1=max(Re_z1);
    set(handles.RP1,'Enable','on');
    set(handles.RP1,'String',num2str(Rp_KK_1));
    Re_z=Re_z1./Rp_KK_1;
    Im_z=Im_z1./Rp_KK_1;
    d=[f1,Re_z,Im_z]; 
    save([comm.dirname,'\','DataSet1_KKT.txt'],'d','-ascii');
    save([comm.dirname,'\','data.gpdat'],'d','-ascii');
    comm.path1=[comm.dirname,'\','DataSet1_KKT.txt'];
    comm.spath1='DataSet1_KKT.txt';
    set(handles.edit1,'String',comm.path1);

    Rp_KK_2=max(Re_z2);
    set(handles.RP2,'Enable','on');
    set(handles.RP2,'String',num2str(Rp_KK_2));
    Re_z=Re_z2./Rp_KK_2;
    Im_z=Im_z2./Rp_KK_2;
    d=[f2,Re_z,Im_z];
    save([comm.dirname,'\','DataSet2_KKT.txt'],'d','-ascii');
    save([comm.dirname,'\','data_val.gpdat'],'d','-ascii');
    comm.path2=[comm.dirname,'\','DataSet2_KKT.txt'];
    comm.spath2='DataSet2_KKT.txt';
    set(handles.edit2,'String',comm.path2);
    Rp_KK=0.8*Rp_KK_1+0.2*Rp_KK_2;
    save([comm.dirname,'\','norm_factor.gpdat'],'Rp_KK','-ascii');

else
    set(handles.RPtext1,'Enable','off');
    set(handles.RPtext2,'Enable','off');
    set(handles.loglog1,'Enable','off');
    set(handles.semilog1,'Enable','off');
    set(handles.loglog2,'Enable','off');
    set(handles.semilog2,'Enable','off');
    set(handles.RP1,'Enable','off')
    set(handles.RP2,'Enable','off')
    set(handles.edit1,'String',no_kkt.path1);
    set(handles.edit2,'String',no_kkt.path2);
    comm.path1=no_kkt.path1;
    comm.path2=no_kkt.path2;
    comm.spath1=no_kkt.spath1;
    comm.spath2=no_kkt.spath2;
end

% KKT plot:
function KKT(hObject,eventdata,handles,dataset,llsl) 
global comm
if dataset==1
    plot_kkt1(comm,llsl)
else
    plot_kkt2(comm,llsl)
end

% Create Axes:
function CreateAxes(handles)
global data data_val u1 u2 comm

data=load([comm.dirname,'\','data.gpdat'],'-ascii');
data_val=load([comm.dirname,'\','data_val.gpdat'],'-ascii');

u1=(2.*pi.*data(:,1));
u2=(2.*pi.*data_val(:,1));

semilogx(handles.ax1,u1,data(:,2),u2,data_val(:,2))
xlabel(handles.ax1,'\omega','FontWeight','bold','FontUnits','pixels','FontSize',18)
ylabel(handles.ax1,'Z''','FontWeight','bold','FontUnits','pixels','FontSize',16)
legend(handles.ax1,'set1','set2','northwest')
title(handles.ax1,'Re vs. \omega','FontWeight','bold','FontUnits','pixels','FontSize',16)

semilogx(handles.ax2,u1,-data(:,3),u2,-data_val(:,3))
legend(handles.ax2,'set1','set2','northwest')

if get(handles.CheckBox,'Value')==1
    set(handles.PBView,'Enable','on');
    set(handles.CheckBox,'Value',get(handles.CheckBox,'max'));
    omega=load([comm.dirname,'\','omega.gpdat'],'-ascii');
    w0=omega(1);
    w1=omega(2);
    set(handles.w0,'String',w0);
    set(handles.w1,'String',w1);
    filter=(1+exp(-5.*(log10(u1)-log10(w0))./((log10(w1)-log10(w0))))).^(-1);
    minumum=min(min(data(:,3)),min(data_val(:,3)));

    semilogx(handles.ax2,u1,-data(:,3),u2,-data_val(:,3),u1,-filter*minumum)
    legend(handles.ax2,'set1','set2','filter','northwest')
    set(handles.NotScale,'Visible','on');
    grid on
end

xlabel(handles.ax2,'\omega','FontWeight','bold','FontUnits','pixels','FontSize',18)
ylabel(handles.ax2,'-Z"','FontWeight','bold','FontUnits','pixels','FontSize',16)
title(handles.ax2,'Im vs. \omega','FontWeight','bold','FontUnits','pixels','FontSize',16)

% Create wow1 jpg:
function w0w1_jpg(hObject,eventdata,handles)  
img=imread('ISGP/w0w1.isgp');
image(img);
axis off
axis image

% Create filter jpg:
function filter_jpg(hObject,eventdata,handles) 
img=imread('ISGP/filter1.isgp');
image(img);
axis off
axis image

% Close Button:
function PBClose(hObject,eventdata,handles) 
button=questdlg('Are you sure you want to close the ISGP?','Close Confirmation Dialog','Yes','No','Yes');
if strcmp(button,'Yes')
    delete(handles.screen3);
end

% Help Button:
function PBHelp(hObject,eventdata,handles)  
web http://electroceramics.technion.ac.il/isgp/help.html

% Next Button:
function PBNext(hObject,eventdata,handles) 
global comm LoadSetsFlag no_kkt
% Check if saving files is possible:
if ~isfolder(comm.dirname)
    errordlg('The directory of the project was deleted or moved.','Incorrect File Path','modal');
    return
end

if strcmp(get(handles.edit1,'String'),'') && strcmp(get(handles.edit2,'String'),'')
    errordlg('Please enter Two data sets, and load them.','No data was entered','modal');
    return
end

% check whether the data loaded is the data "entered":
% if the edit boxes differs from the comm.spath#, we know that the
% user had entered or changed the data, so we'll use the edit#.string:
flag=0;
if ~strcmp(comm.spath1,get(handles.edit1,'String'))
    flag=1;
end
if ~strcmp(comm.spath2,get(handles.edit2,'String'))
    flag=1;
end

% if the data was changed, load it:
if flag==1 && strcmp(no_kkt.path1,'')
    button=questdlg('The Data Set Paths where changed. Would you like to load the NEW data sets?','Load Confirmation Dialog','Yes','No','Cancel','Yes');
    switch button
        case 'Cancel'
            return
        case 'Yes'
            comm.path1=get(handles.edit1,'String');
            comm.path2=get(handles.edit2,'String');
            err=LoadFcn(handles,0);
            if err==1
                return
            end
        case 'No'
            set(handles.edit1,'UserData',comm.path1);
            set(handles.edit1,'String',comm.spath1);
            set(handles.edit2,'UserData',comm.path2);
            set(handles.edit2,'String',comm.spath2);
            err=LoadFcn(handles,0);
            if err==1
                return
            end
    end
end

% If the data was not loaded via LoadSets Button, load it:
if LoadSetsFlag==0
    err=LoadFcn(handles,0);
    if err==1
        return
    end
end

if get(handles.check1,'Value')==0
    button=questdlg('You did not use K-K. Your data wont be normalized. would you like to continue?','Load Confirmation Dialog','Yes','No','No');
    if strcmp(button,'No')
        return
    end
end

comm.UseFilter=get(handles.CheckBox,'Value');
if comm.UseFilter==0
    w0=0.00001;
    w1=0.001;
else
    w0=str2double(get(handles.w0,'string'));
    w1=str2double(get(handles.w1,'string'));
end

omega=[w0,w1]; 
save([comm.dirname,'\','omega.gpdat'],'omega','-ascii');

comm.spath1=get(handles.edit1,'String');
comm.spath2=get(handles.edit2,'String');
comm.pos=get(handles.screen3,'Position');
save([comm.dirname,'\','comm.mat'],'comm');
comm.plot=1;
Ramp(comm)
delete(handles.screen3)

% Back Button:
function PBBack(hObject,eventdata,handles) 
global comm
comm.UseFilter=get(handles.CheckBox,'Value');
comm.pos=get(handles.screen3,'Position');

if ~isfolder(comm.dirname)
    errordlg('The directory of the project was deleted or moved.','Incorrect File Path','modal');
    return
end

save([comm.dirname,'\','comm.mat'],'comm');
rmdir(comm.dirname,'s');
project(comm)
delete(handles.screen3)

% Browse 1 Button:
function PBBrowse1(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 1');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit1,'UserData',str1);
    
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit1,'String',str1);%was str2
    comm.path1=str1;
    comm.spath1=str1;%was str2
end

% Additional Sets:
function additionalsets1(hObject,eventdata,handles)
global comm
additionalsets(comm)
delete(handles.screen3)

% Browse 2 Button:
function PBBrowse2(hObject,eventdata,handles) 
global comm
[FileName,PathName]=uigetfile('*.*','Load Set 2');
% check if any data was entered:
if FileName~=0
    % store the data in one string:
    str1=[PathName,FileName];
    % save the full path in UserData:
    set(handles.edit2,'UserData',str1);
   
    % is str>40 show the short path:
    %if length(str1)>40
        %for ii=1:(34-length(FileName)-4)
            %str2(ii)=str1(ii); 
        %end
        %str2(ii+1)='.';
        %str2(ii+2)='.';
        %str2(ii+3)='.';
        %str2(ii+4)='.';
        %str2(ii+5)='\';
        %for jj=ii+6:35
            %str2(jj)=FileName(jj-ii-5); 
        %end
    %else
        %str2=str1;
    %end

    %if length(FileName)>30
        %str2=FileName;
    %end

    % save the short/full path in String:
    set(handles.edit2,'String',str1);%was str2
    comm.path2=str1;
    comm.spath2=str1;%was str2
end

% Filter %
% CheckBox:
function FilterCheckBox(hObject,eventdata,handles) 
global comm
if (get(hObject,'Value')==get(hObject,'Max'))
    % Checkbox is checked
    set(handles.PBView,'Enable','on');
    comm.UseFilter=1;
else
    % Checkbox is not checked
    set(handles.PBView,'Enable','off');
    comm.UseFilter=0;
end

% View Filter %
% Button:
function PBViewFilter(hObject,eventdata,handles) 
global data data_val u1 u2 comm

if strcmpi(get(handles.ax1,'Visible'),'off')
    errordlg('Please load the data sets.','No data was loaded','modal');
    return
end

% get w0, w1:
w0=str2double(get(handles.w0,'string'));
w1=str2double(get(handles.w1,'string'));

filter=(1+exp(-5.*(log10(u1)-log10(w0))./((log10(w1)-log10(w0))))).^(-1);
minumum=min(min(data(:,3)),min(data_val(:,3)));

% plot filter:
semilogx(handles.ax2,u1,-data(:,3),u2,-data_val(:,3),u1,-filter*minumum)
xlabel(handles.ax2,'\omega','FontWeight','bold','FontUnits','pixels','FontSize',18)
ylabel(handles.ax2,'-Z"','FontWeight','bold','FontUnits','pixels','FontSize',16)
legend(handles.ax2,'set1','set2','filter')
title(handles.ax2,'Im vs. \omega','FontWeight','bold','FontUnits','pixels','FontSize',16)
set(handles.NotScale,'Visible','on');
grid on
omega=[w0,w1];

if ~isfolder(comm.dirname)
    errordlg('The directory specified does not exist.','Incorrect File Path','modal');
    return
end
save([comm.dirname,'\','omega.gpdat'],'omega','-ascii');

% Load Sets %
% Button:
function PBLoadSets(hObject,eventdata,handles) 
global comm LoadSetsFlag
LoadSetsFlag=1;
% if the edit boxes differs from the comm.spath#, we know that the
% user had entered or changed the data, so we'll use the edit#.string:
if ~strcmp(comm.spath1,get(handles.edit1,'String'))
    comm.path1=get(handles.edit1,'String');
end

if ~strcmp(comm.spath2,get(handles.edit2,'String'))
    comm.path2=get(handles.edit2,'String');
end

% check if any data was entered:
if isempty(comm.path1) || isempty(comm.path2)
    errordlg('Please enter Two data sets.','No data was entered','modal');
else
    err=LoadFcn(handles,1);
    if err==0
        comm.plot=1;
    end
end

% LoadFnc:
function err=LoadFcn(handles,PlotGraph)
% This function check if the paths entered exist, and loads the data sets into GPDAT files.
% PlotGraph is 1 when called from PBLoadSets. The function will plot the data.
% PlotGraph is 0 when called from PBNext. The function will not plot the data to save time.
global data data_val u1 u2 comm
err=0;
if strcmp(comm.path1,'')
    errordlg('Enter Data Set 1.','Incorrect File Path','modal');
    err=1;
    return
end

if strcmp(comm.path2,'')
    errordlg('Enter Data Set 2.','Incorrect File Path','modal');
    err=1;
    return
end

a=comm.path1(length(comm.path1):-1:length(comm.path1)-3);
b=comm.path2(length(comm.path2):-1:length(comm.path2)-3);

if ~strcmp(a,'txt.')
    errordlg('Data Set 1 is not a text file','Incorrect File Path','modal');
    err=1;
    return
end

if ~strcmp(b,'txt.')
    errordlg('Data Set 2 is not a text file','Incorrect File Path','modal');
    err=1;
    return
end

% check the paths:
flags=checkpaths(comm.path1,comm.path2);
if sum(flags)<4
    if flags(1)==0
        errordlg('Data Set 1 was not entered correctly. The directory specified does not exist.','Incorrect File Path','modal');
        err=1;
        return
    end
    if flags(2)==0
        errordlg('Data Set 2 was not entered correctly. The directory specified does not exist.','Incorrect File Path','modal');
        err=1;
        return
    end
    if flags(3)==0
        errordlg('Data Set 1 was not entered correctly. The file specified does not exist.','Incorrect File Path','modal');
        err=1;
        return
    end
    if flags(4)==0
        errordlg('Data Set 2 was not entered correctly. The file specified does not exist.','Incorrect File Path','modal');
        err=1;
        return
    end
end

% Load data and save to file:
data=load(comm.path1);
data_val=load(comm.path2);
u1=(2.*pi.*data(:,1));
u2=(2.*pi.*data_val(:,1));
if ~isfolder(comm.dirname)
    errordlg('The directory specified does not exist.','Incorrect File Path','modal');
    return
end

filename=[comm.dirname,'\','data.gpdat'];
save(filename,'data','-ascii')
filename=[comm.dirname,'\','data_val.gpdat'];
save(filename,'data_val','-ascii')

if PlotGraph==1
    semilogx(handles.ax1,u1,data(:,2),u2,data_val(:,2))
    xlabel(handles.ax1,'\omega','FontWeight','bold','FontUnits','pixels','FontSize',18)
    ylabel(handles.ax1,'Z','FontWeight','bold','FontUnits','pixels','FontSize',16)
    legend(handles.ax1,'set1','set2','northwest')
    title(handles.ax1,'Re vs. \omega','FontWeight','bold','FontUnits','pixels','FontSize',16)

    semilogx(handles.ax2,u1,-data(:,3),u2,-data_val(:,3))
    legend(handles.ax2,'set1','set2','northwest')

    if comm.UseFilter==1
        w0=str2double(get(handles.w0,'String'));
        w1=str2double(get(handles.w1,'String'));
        filter=(1+exp(-5.*(log10(u1)-log10(w0))./((log10(w1)-log10(w0))))).^(-1);
        minumum=min(min(data(:,3)),min(data_val(:,3)));

        semilogx(handles.ax2,u1,-data(:,3),u2,-data_val(:,3),u1,-filter*minumum)
        legend(handles.ax2,'set1','set2','filter','northwest')
        set(handles.NotScale,'Visible','on');
        grid on
    else
        set(handles.NotScale,'Visible','off');
    end

    xlabel(handles.ax2,'\omega','FontWeight','bold','FontUnits','pixels','FontSize',18)
    ylabel(handles.ax2,'-Z"','FontWeight','bold','FontUnits','pixels','FontSize',16)
    title(handles.ax2,'Im vs. \omega','FontWeight','bold','FontUnits','pixels','FontSize',16)
end

% Load header:
function header(hObject,eventdata,handles) 
img=imread('ISGP/h2.isgp');
image(img);
axis off
axis image

%Load slogo:
%function slogo(hObject,eventdata,handles) %#ok<INUSD>
%img=imread('ISGP/slg.isgp');
%image(img);
%axis off
%axis image