function [lb,ub]=lbub(x,pop,u)
% [lb,ub]=lbub(x,pop)
% Usage: Determen the lb - lower bound,ub - upper bound for fmincon
%        x = length of the guess vector
%        pop = gene
%        u = log10(tau)
% Written by: Yehu-David Horev
% Modified by: Maor Asher, Arthur Doroshev
%--------------------------------------------------------------------------
global par
a=length(x);
lb=[];
ub=[];

% entering the upper bound (ub) & lower bound (lb) for each peak for the calculation
force=0;
if ~strcmp(par.forcedpick,'')
    force=1;
end
            
for i=1:length(pop)
    % Pseudo Delta
    if pop(i)=='D'
        if force==1
            %  [  ,height,tau0                   ]
            lb=[lb,1e-5  ,-par.forcedpickrange(2)]; 
            ub=[ub,inf   ,-par.forcedpickrange(1)]; 
        else
            %  [  ,height,tau0         ]
            lb=[lb,1e-5  ,-par.delta.ub]; 
            ub=[ub,inf   ,-par.delta.lb]; 
        end
        
    % R - Low Tau Delta Function
    elseif pop(i)=='Y'    
        %  [  ,a   ,x0       ]
        lb=[lb,1e-5,-par.R.ub]; 
        ub=[ub,inf ,-par.R.lb];
        
    % U - High Tau Delta Function
    elseif pop(i)=='U'    
        %  [  ,a   ,x0       ]
        lb=[lb,1e-5,-par.U.ub]; 
        ub=[ub,inf ,-par.U.lb];
        
    % Gaussian
    elseif pop(i)=='G'
        if force==1
            %  [  ,a   ,x0                     ,s                          ]
            lb=[lb,1e-5,-par.forcedpickrange(2),(u(1)-u(end))./2./length(u)]; 
            ub=[ub,inf ,-par.forcedpickrange(1),inf                        ]; 
        else
            %  [  ,a   ,x0           ,s                          ]
            lb=[lb,1e-5,-par.gauss.ub,(u(1)-u(end))./2./length(u)]; 
            ub=[ub,inf ,-par.gauss.lb,inf                        ]; 
        end
        
    % Lorentzian
    elseif pop(i)=='L'
        if force==1
            %  [  ,a   ,x0                     ,s                          ]
            lb=[lb,1e-5,-par.forcedpickrange(2),(u(1)-u(end))./2./length(u)]; 
            ub=[ub,inf ,-par.forcedpickrange(1),inf                        ]; 
        else
            %  [  ,a   ,x0            ,s                          ]
            lb=[lb,1e-5,-par.lorenz.ub,(u(1)-u(end))./2./length(u)]; 
            ub=[ub,inf ,-par.lorenz.lb,inf                        ];
        end
        
    % Sech    
    elseif pop(i)=='S'
        %  [  ,a   ,x0          ,s                          ]
        lb=[lb,1e-5,-par.sech.ub,(u(1)-u(end))./2./length(u)]; 
        ub=[ub,inf ,-par.sech.lb,inf                        ];
        
    % Cole - Cole    
    elseif pop(i)=='C'
        %  [  ,A   ,x0          ,alpha  ]
        lb=[lb,1e-5,-par.cole.ub,1e-5   ]; 
        ub=[ub,inf ,-par.cole.lb,0.99999];
        
    % Pearson VII    
    elseif pop(i)=='P'
        %  [   ,a  ,x0             ,s                          ,m  ]
        lb=[lb,1e-5,-par.pearson.ub,(u(1)-u(end))./2./length(u),0  ]; 
        ub=[ub,inf ,-par.pearson.lb,inf                        ,inf];
        
    % Losev
    elseif pop(i)=='A'
        %  [  ,a   ,x0           ,s1                         ,s2                         ]
        lb=[lb,1e-5,-par.losev.ub,(u(1)-u(end))./2./length(u),(u(1)-u(end))./2./length(u)]; 
        ub=[ub,inf ,-par.losev.lb,inf                        ,inf                        ]; 
        
    % HN    
    elseif pop(i)=='H'
        %  [  ,A   ,x0        ,alpha  ,gamma  ]
        lb=[lb,1e-5,-par.hn.ub,1e-5   ,1e-5   ]; 
        ub=[ub,inf ,-par.hn.lb,0.99999,0.99999];
        
    % KF    
    elseif pop(i)=='B'
        %  [   ,A  ,x0        ,alpha  ]
        lb=[lb,1e-5,-par.kf.ub,1e-5   ];
        ub=[ub,inf ,-par.kf.lb,0.99999];
        
    % Assymetric Gaussian
    elseif pop(i)=='F'
        %  [  ,a   ,x0            ,s1                         ,s2                         ]
        lb=[lb,1e-5,-par.agauss.ub,(u(1)-u(end))./2./length(u),(u(1)-u(end))./2./length(u)]; 
        ub=[ub,inf ,-par.agauss.lb,inf                        ,inf                        ];
        
    % Assymetric Lorentzian
    elseif pop(i)=='K'
        %  [  ,a   ,x0             ,s1                         ,s2                         ]
        lb=[lb,1e-5,-par.alorenz.ub,(u(1)-u(end))./2./length(u),(u(1)-u(end))./2./length(u)]; 
        ub=[ub,inf ,-par.alorenz.lb,inf                        ,inf                        ];
        
    % Assymetric Sech
     elseif pop(i)=='E'
        %  [  ,a   ,x0            ,s1                        ,s2                         ]
        lb=[lb,1e-5,-par.asech.ub,(u(1)-u(end))./2./length(u),(u(1)-u(end))./2./length(u)]; 
        ub=[ub,inf ,-par.asech.lb,inf                        ,inf                        ];

    % Pseudo Voigt    
    elseif pop(i)=='V'
        %  [   ,a  ,x0                 ,s                          ,g                          ,f]
        lb=[lb,1e-5,-par.pseudovoigt.ub,(u(1)-u(end))./2./length(u),(u(1)-u(end))./2./length(u),0];
        ub=[ub,inf ,-par.pseudovoigt.lb,inf                        ,inf                        ,1];
    end
    force=0;
end
lb=lb(1:a);
ub=ub(1:a);