function [o_mod,x]=parfit(i_mod,u,y,yr)
% [o_mod,x]=gp_parfit(i_mod,u,y)
% Usage: This computes the optimal parameters in model i_mod and returns them in o_mod, given also:
%        u = log10(tau)
%        y = Im 
%        yr = Re
% o_mod is the optimized model & x is the parameters vector
% Written by A.T., 1.03.06
% Modified by: Yehu-David Horev, Arthur Doroshev
%--------------------------------------------------------------------------
% Making all vector column vectors:
u=u(1:end,:); %u=log10(tau)
y=y(1:end,:); %y=Im
yr=yr(1:end,:); %yr=Re

% constb3a puts inside the model the missing [1] => G turns into G([1],u1+[1],[1])
i_mod=constb3a(i_mod);

% Replace constant markes [1] by variables x($).
i_mod=strrep(i_mod,'[1]','x($)');

% finding positions of $
fi=strfind(i_mod,'$');

% replacing $ with numbers
xtt=[];
for i=1:length(fi)
    if i==1
        xtmp=i_mod(1:fi(i)-1);
        xtt=[xtt,xtmp,num2str(i)]; 
    else
        xtmp=i_mod(fi(i-1)+1:fi(i)-1);
        xtt=[xtt,xtmp,num2str(i)]; 
    end
end
xtmp=i_mod(fi(i)+1:length(i_mod));
i_mod=[xtt,xtmp];
i_mod=strrep(i_mod,'u1','u(:,1)');
%--------------------------------------------------------------------------
% smart initial guess
% options for 'fmincon' guess function 
%options=optimset('display','off','MaxFunEvals',200,'MaxIter',2000,'TolX',1e-6,'TolFun',1e-5,'TolCon',1e-6,'DerivativeCheck','off','Algorithm','sqp');
options=optimoptions('fmincon','Algorithm','sqp','display','off','CheckGradients',false,'MaxFunctionEvaluations',10,'MaxIterations',10);
% turning off Matlab warnings
%warning ('off');

x=[];
% the guess is done in interations when every parameter is adjusted step by step
for i=1:length(fi)
    j_mod=i_mod;
    for j=i+1:length(fi)
        % replace [1] with a parameter to be adjusted
        j_mod=strrep(j_mod,['x(' num2str(j) ')'],'[1]');
    end
    % make initial guess
    a=guess(x,u,y,i_mod);
    % adjust guess vector
    x0=[x,a];
    % try
    % crate lower & upper bounds for the guess
    [lb,ub]=lbub(x0,i_mod,u);
    % create guess with 'fmincon' when 'modfmin' is the target function
    [x,fval]=fmincon('modfmin',x0,[],[],[],[],lb,ub,[],options,j_mod,u,y,yr); 
end
x0=x;
%--------------------------------------------------------------------------
% final optimization
%options=optimset('display','off','MaxFunEvals',2000,'MaxIter',2000,'TolX',1e-6,'TolFun',1e-5,'TolCon',1e-6,'DerivativeCheck','off','Algorithm','sqp');
options=optimoptions('fmincon','Algorithm','sqp','display','off','CheckGradients',false,'MaxFunctionEvaluations',3000,'MaxIterations',3000);
% create guess with 'fmincon' when 'modfmin' is the target function
[x,fval]=fmincon('modfmin',x0,[],[],[],[],lb,ub,[],options,j_mod,u,y,yr); 
digits(5)
x=real(x);
%--------------------------------------------------------------------------
% Insert least squares fit constants back into string
x_find=strfind(i_mod,'x');
x_tmp=[]; 
x_tmp=i_mod(1:x_find(1)-1);
xx=[];
for i=1:length(x_find)
    if i==1
        xx=[xx,x_tmp,'[',num2str(x(i)),']']; 
    elseif i<10 
        x_tmp=i_mod(x_find(i-1)+4:x_find(i)-1);
        xx=[xx,x_tmp,'[',num2str(x(i)),']']; 
    elseif i==10
        x_tmp=i_mod(x_find(i-1)+4:x_find(i)-1);
        xx=[xx,x_tmp,'[',num2str(x(i)),']']; 
    elseif i>10
        x_tmp=i_mod(x_find(i-1)+5:x_find(i)-1);
        xx=[xx,x_tmp,'[',num2str(x(i)),']']; 
    end
end

if i>=10
    xtmp=i_mod(x_find(i)+5:length(i_mod));
elseif i<10
    xtmp=i_mod(x_find(i)+4:length(i_mod));
end
o_mod=[xx,xtmp];
% Strip out term-by-term corrections inserted before.
o_mod=strrep(o_mod,'u(:,1)','u1');
% sorting by the log(tau)
spl=regexp(o_mod,'[A-Z]\([^\)]+\)','match');
vec=sscanf(o_mod,'%*[A-Z]([%*f],u1+[%f],[%*f])+');
[~,idx]=sort(vec,'descend');
o_mod=join(spl(idx),'+');
o_mod=o_mod{1};