function project(varargin)
% project(varargin)
% Usage: This page asks the user wether he wants to create a new project or to continue an old one.
% It also contains the "save movie" option.
% varargin = {comm}
% The comm structure is the communication factor between the screens.
% comm.pos = The last figure position. The current figure will take its place.
% comm.dirname = The name of the work directory.
% comm.name = The project's name.
% comm.movie = Whether the "save movie" check box was checked (project).
% comm.plot = Whether to plot axexs on startup (LoadData)
% comm.UseFilter = Whether the filter was used the last time (LoadData).
% comm.LoadParamaters = Whether the user has changed any of the paramaters (Parameters).
% comm.path1 = The Path to DataSet1.
% comm.path2 = The Path to DataSet2.
% comm.spath1 = The short Path name to DataSet1.
% comm.spath2 = The short Path name to DataSet2.
% NOTE:
% comm.dirname is the WORKING dir name. 
% comm.path# is the DATA dir name.
% Credits: Alex Tesler, Yehu David-Horev, Alon Dana, Maor Asher.
% Modified by: Arthur Doroshev
%--------------------------------------------------------------------------
global comm if_back omega_duplicate
if_back=0;    
if nargin==0
    % Set Default values:
    comm.pos=[240,227,800,550];
    comm.dirname='';
    comm.existingfile='';
    comm.ramp(1:2,1:5)=-1;
    comm.name='';
    comm.movie=0;
    comm.plot=0;
    comm.UseFilter=0;
    comm.LoadParamaters=0;
    comm.path1='';
    comm.path2='';
    comm.spath1='';
    comm.spath2='';
    comm.check='';
    comm.kktcheckbox='';
else
    comm=varargin{1};
    if_back=1;
end

if comm.check==1
    comm.Abort=0;
end

screen2=figure('Position',comm.pos,'Color','White','MenuBar','none','NumberTitle','off','Name','Impedance Spectroscopy Genetic Programming','Resize','off','Tag','screen2');
if nargin==0
    movegui('center');
end

handles=guihandles;
guidata(screen2,handles);

%------------ Buttons: ------------%
% Close:
handles.close=uicontrol('Style','pushbutton','Units','pixels','Position',[10,10,70,25],'FontSize',8,'FontWeight','bold','String','Close');
    
% Help:
handles.help=uicontrol('Style','pushbutton','Units','pixels','Position',[100,10,70,25],'FontSize',8,'FontWeight','bold','String','Help');
    
% Next:
handles.next=uicontrol('Style','pushbutton','Units','pixels','Position',[720,10,70,25],'FontSize',8,'FontWeight','bold','String','Next  >');
    
% Back:
handles.back=uicontrol('Style','pushbutton','Units','pixels','Position',[630,10,70,25],'FontSize',8,'FontWeight','bold','String','<  Back');
    
% Header:
axes('Parent',screen2,'Units','pixels','Position',[250,350,300,300],'CreateFcn',{@header,handles});
    
% slogo:
%axes('Units','pixels','Position',[250,300,50,50],'CreateFcn',{@slogo,handles});
    
% text: "Please enter a name for the new project (directory name)."
handles.pathText1=uicontrol('Style','text','Units','pixels','Position',[42,405,750,20],'BackgroundColor','White','FontSize',12,'HorizontalAlignment','left','String','Please enter a name for the new project (It will also be the name of the directory).');
    
% text: "Please enter the name or the full path to your project."
handles.pathText2=uicontrol('Style','text','Units','pixels','Position',[42,265,750,20],'BackgroundColor','White','Enable','off','FontSize',12,'HorizontalAlignment','left','String','Please enter the name or the full path to your project.');
    
% text: "Name:"
uicontrol('Style','text','Units','pixels','Position',[42,375,100,20],'BackgroundColor','White','FontSize',12,'HorizontalAlignment','left','String','Name:');
    
% text: "Path:"
handles.pathText1 = uicontrol('Style','text','Units','pixels','Position',[42,235,100,20],'BackgroundColor','White','Enable','off','FontSize',12,'HorizontalAlignment','left','String','Path:');
    
% edit 1:
handles.edit1=uicontrol('Style','edit','Units','pixels','Position',[95,375,200,20],'BackgroundColor','White','FontSize',10,'HorizontalAlignment','left','String',comm.name,'Tag','edit1');
   
% edit 2:
handles.edit2=uicontrol('Style','edit','Units','pixels','Position',[95,235,300,20],'KeyPressFcn',{@Edit2Down,handles},'BackgroundColor','White','FontSize',10,'Enable','off','HorizontalAlignment','left','String',comm.existingfile,'Tag','edit2');
    
% Browse:
handles.browse=uicontrol('Style','pushbutton','Units','pixels','Enable','off','FontSize',8,'Position',[405,232.5,70,25],'String','Browse');
    
% Check Box:
handles.check1=uicontrol('Style','checkbox','Units','pixels','Position',[42,290,500,20],'BackgroundColor','White','FontSize',12,'Max',1,'Min',0,'CallBack',{@CheckBack,handles},'Value',0,'String','Would you like to load data from an existing project?');
        
%------------ Create Movie Panel: ------------%
hpanel=uipanel('Title','Create Movie','FontSize',10,'Parent',handles.screen2,'Units','pixels','Position',[25,80,680,100],'BackgroundColor','White','Tag','MoviePanel');
    
% text: "ISGP can save a movie..."
uicontrol('Style','text','Parent',hpanel,'Units','pixels','Position',[15,26,640,50],'BackgroundColor','White','FontSize',12,'HorizontalAlignment','left','String','ISGP can save a movie of the convergence for each run. The movie will be saved in the directory of your project. Would you like to save a movie of your work?');
handles.check=uicontrol('Style','checkbox','Parent',hpanel,'Units','pixels','Position',[5,5,350,20],'BackgroundColor','White','FontSize',12,'Max',1,'Min',0,'String',' Yes, save a movie of my work.');

if comm.movie==1
    set(handles.check,'Value',1);
end

if ~strcmp(comm.existingfile,'')
    set(handles.check1,'Value',1);
    set(handles.browse,'Enable','on');
    set(handles.edit2,'Enable','on');
    set(handles.pathText1,'Enable','on');
    set(handles.pathText2,'Enable','on');
end

% Define Buttons' Callbacks:
set(handles.close,'CallBack',{@PBClose,handles});
set(handles.help,'CallBack',{@PBHelp,handles});
set(handles.next,'CallBack',{@PBNext,handles});
set(handles.back,'CallBack',{@PBBack,handles});
set(handles.browse,'CallBack',{@PBBrowse,handles});
set(handles.edit1,'KeyPressFcn',{@Edit1Down,handles});
set(handles.edit2,'KeyPressFcn',{@Edit2Down,handles});
        
% additional sets/runs:
if comm.check==1
    comm.name='';
    comm.plot=0;
    [status,message,messageid]=mkdir(pwd,comm.dirname); 
    save([comm.dirname,'\','omega_duplicate.gpdat'],'omega_duplicate','-ascii');
    if ~strcmp(message,'')
        if if_back==0
        errordlg(message,'error','modal');
        return
        end
    end
    [status,message]=mkdir([comm.dirname,'\output']); 
    comm.dirname=[pwd,'\',comm.dirname];
    comm.plot=0;
    %comm.UseFilter=0;
    comm.LoadParamaters=0;
    if get(handles.check1,'Value')==0
        comm.existingfile='';
    end
    comm.movie=get(handles.check,'Value');
    comm.pos=get(handles.screen2,'Position');
    delete(handles.screen2)
    LoadData(comm)
end

%------------ Functions: ------------%   
% Create:
%function CreateFunction()
%clc

% Close Button:
function PBClose(hObject,eventdata,handles) 
button=questdlg('Are you sure you want to close the ISGP?','Close Confirmation Dialog','Yes','No','Yes');
if strcmp(button,'Yes')
    delete(handles.screen2)
end
    
% Help Button:
function PBHelp(hObject,eventdata,handles)  
web http://electroceramics.technion.ac.il/ISGP/help.html

% Next Button:
function PBNext(hObject,eventdata,handles) 
global comm if_back
check=get(handles.check1,'Value');
if check==1
    % The user has chosen to open an existing project
    comm.existingfile=get(handles.edit2,'String');  
    if strcmp(comm.existingfile,'')
        errordlg('No Name was entered for the existing project.','error','modal');
        return
    end
    comm.plot=1;
    comm.LoadParamaters=1;
    try
    [pp,po,f,ff,disc]=loadolddata(comm.existingfile);  
    catch
        errordlg('Project entered is invalid','error','modal')
        return
    end
    comm.existingfile=get(handles.edit2,'String');
end

if if_back==1
    if strcmp(comm.name,get(handles.edit1,'String'))
        if_back=1;
    else
        if_back=0;
    end
end

comm.name='';
comm.dirname=get(handles.edit1,'String');
comm.plot=0;
if strcmp(comm.dirname,'')
    errordlg('No name was entered for the new project.','error','modal');
    return
end

[status,message,messageid]=mkdir(pwd,comm.dirname);  
if ~strcmp(message,'')
    if if_back==0
        errordlg(message,'error','modal');
        return
    end
end

[status,message]=mkdir([comm.dirname,'\output']); 
if ~strcmp(message,'')
    if if_back==0
        errordlg(message,'error','modal');
        return
    end
end

comm.dirname=[pwd,'\',comm.dirname];
comm.plot=0;
comm.UseFilter=0;
comm.LoadParamaters=0;
comm.path1='';
comm.path2='';
comm.spath1='';
comm.spath2='';
if get(handles.check1,'Value')==0
    comm.existingfile='';
end

comm.movie=get(handles.check,'Value');
comm.pos=get(handles.screen2,'Position');
LoadData(comm)
delete(handles.screen2)
       
% Back Button:
function PBBack(hObject,eventdata,handles) 
global comm
comm.pos=get(handles.screen2,'Position');
comm.movie=get(handles.check,'Value');
if get(handles.check1,'Value')==0
    comm.existingfile=''; 
end

welcome(comm)
delete(handles.screen2)
                   
% Browse Button:
function PBBrowse(hObject,eventdata,handles) 
[FileName,path]=uigetfile('*.mat','Please enter the project you want to continue:');
str=[path,'\',FileName];
if ~strcmp(path,'') || ~strcmp(FileName,'')
    set(handles.edit2,'string',str);
end

% Load header:
function header(hObject,eventdata,handles) 
img=imread('ISGP/h1.isgp');
image(img);
axis off
axis image

%Load slogo:
%function slogo(hObject,eventdata,handles)  
%img=imread('ISGP/slg.isgp');
%image(img);
%axis off
%axis image

% CheckBox CallBack:
function CheckBack(hObject,eventdata,handles)  
if (get(hObject,'Value')==get(hObject,'Max'))
    set(handles.browse,'Enable','on');
    set(handles.edit2,'Enable','on');
    set(handles.pathText1,'Enable','on');
    set(handles.pathText2,'Enable','on');
else
    set(handles.browse,'Enable','off');
    set(handles.edit2,'Enable','off');
    set(handles.pathText1,'Enable','off');
    set(handles.pathText2,'Enable','off');
end

% Edit 1 Button Down Function:
function Edit1Down(hObject,eventdata,handles)  

% Edit 2 Button Down Function:
function Edit2Down(hObject,eventdata,handles) 